# cc.SCPI

The Standard Commands for Programmable Instruments (SCPI) defines a standard for syntax and commands to use in controlling programmable test and measurement devices. This Python module provides a wrapper for controlling various lab instruments.

## Installation

```bash
pip install cc-scpi
```
